@@ -1,5 +1,6 @@
+import six
+
 from django.template import Library
-from django.conf import settings
 
 from django_bitly.models import Bittle
 from django_bitly.exceptions import BittleException
@@ -24,7 +25,10 @@ def bitlify(value):
             url = value.get_absolute_url
         return url
     except (BittleException, Bittle.DoesNotExist):
-        return value.get_absolute_url()
+        if isinstance(value, six.string_types):
+            return value
+        else:
+            return value.get_absolute_url()
 
 
 @register.filter
